@@ -1,13 +1,25 @@
-/*
-    This file is part of the KDE libraries
-    SPDX-FileCopyrightText: 1997-1999 Matthias Kalle Dalheimer <kalle@kde.org>
-    SPDX-FileCopyrightText: 1997-2000 Matthias Ettrich <ettrich@troll.no>
-    SPDX-FileCopyrightText: 1998-2005 Stephan Kulow <coolo@kde.org>
-    SPDX-FileCopyrightText: 1999-2004 Waldo Bastian <bastian@kde.org>
-    SPDX-FileCopyrightText: 2001-2005 Lubos Lunak <l.lunak@kde.org>
-    SPDX-FileCopyrightText: 2008 Aaron Seigo <aseigo@kde.org>
+/* This file is part of the KDE libraries
+    Copyright (c) 1997-1999 Matthias Kalle Dalheimer <kalle@kde.org>
+    Copyright (c) 1997-2000 Matthias Ettrich <ettrich@troll.no>
+    Copyright (c) 1998-2005 Stephan Kulow <coolo@kde.org>
+    Copyright (c) 1999-2004 Waldo Bastian <bastian@kde.org>
+    Copyright (c) 2001-2005 Lubos Lunak <l.lunak@kde.org>
+    Copyright (C) 2008 Aaron Seigo <aseigo@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #ifndef _KTOOLINVOCATION_H
@@ -15,16 +27,12 @@
 
 #include <kservice_export.h>
 
-#if KSERVICE_ENABLE_DEPRECATED_SINCE(5, 89)
-#include <QByteArray>
-#include <QExplicitlySharedDataPointer>
 #include <QObject>
+#include <QByteArray>
 #include <QStringList>
 
 class QUrl;
 class KToolInvocationPrivate;
-class KService;
-typedef QExplicitlySharedDataPointer<KService> KServicePtr;
 
 /**
  * @class KToolInvocation ktoolinvocation.h <KToolInvocation>
@@ -63,13 +71,13 @@ typedef QExplicitlySharedDataPointer<KService> KServicePtr;
  */
 class KSERVICE_EXPORT KToolInvocation : public QObject
 {
+
     Q_OBJECT
 private:
     KToolInvocation();
-
 public:
     // @internal
-    ~KToolInvocation() override;
+    ~KToolInvocation();
     static KToolInvocation *self();
 
 public Q_SLOTS:
@@ -87,10 +95,9 @@ public Q_SLOTS:
      * using QUrl::setPath(address) and a query item of "subject" for the subject.
      */
     KSERVICE_DEPRECATED_VERSION(5, 0, "Use QDesktopServices::openUrl(mailtoURL), using QUrl::setPath(address) and a query item of \"subject\" for the subject")
-    static void invokeMailer(const QString &address, const QString &subject, const QByteArray &startup_id = QByteArray());
-#endif
+    static void invokeMailer(const QString &address, const QString &subject,
+                             const QByteArray &startup_id = QByteArray());
 
-#if KSERVICE_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * Invokes the standard email application.
      *
@@ -102,7 +109,8 @@ public Q_SLOTS:
      * @deprecated since 5.0, use QDesktopServices::openUrl(mailtoURL)
      */
     KSERVICE_DEPRECATED_VERSION(5, 0, "Use QDesktopServices::openUrl(const QUrl&)")
-    static void invokeMailer(const QUrl &mailtoURL, const QByteArray &startup_id = QByteArray(), bool allowAttachments = false);
+    static void invokeMailer(const QUrl &mailtoURL, const QByteArray &startup_id = QByteArray(),
+                             bool allowAttachments = false);
 #endif
 
     /**
@@ -119,14 +127,9 @@ public Q_SLOTS:
      * @param attachURLs  List of URLs to be attached to the mail.
      * @param startup_id for app startup notification, "0" for none,
      *           "" ( empty string ) is the default
-     * @deprecated Since 5.89, use KEMailClientLauncherJob instead
      */
-    KSERVICE_DEPRECATED_VERSION(5, 89, "use KEMailClientLauncherJob instead")
-    static void invokeMailer(const QString &to,
-                             const QString &cc,
-                             const QString &bcc,
-                             const QString &subject,
-                             const QString &body,
+    static void invokeMailer(const QString &to, const QString &cc, const QString &bcc,
+                             const QString &subject, const QString &body,
                              const QString &messageFile = QString(),
                              const QStringList &attachURLs = QStringList(),
                              const QByteArray &startup_id = QByteArray());
@@ -135,7 +138,7 @@ public Q_SLOTS:
     /**
      * Invokes the user's preferred browser.
      * Note that you should only do this when you know for sure that the browser can
-     * handle the URL (i.e. its MIME type). In doubt, if the URL can point to an image
+     * handle the URL (i.e. its mimetype). In doubt, if the URL can point to an image
      * or anything else than HTML, prefer to use new KRun( url ).
      *
      * See also <a
@@ -148,26 +151,11 @@ public Q_SLOTS:
      * @deprecated since 5.0, use QDesktopServices::openUrl(url)
      */
     KSERVICE_DEPRECATED_VERSION(5, 0, "Use QDesktopServices::openUrl(const QUrl&)")
-    static void invokeBrowser(const QString &url, const QByteArray &startup_id = QByteArray());
+    static void invokeBrowser(const QString &url,
+                              const QByteArray &startup_id = QByteArray());
 #endif
 
     /**
-     * Invokes the standard terminal application.
-     *
-     * @param command the command to execute, can be empty.
-     * @param envs ENV variables for the invoked terminal command
-     * @param workdir the initial working directory, can be empty.
-     * @param startup_id for app startup notification, "0" for none,
-     *           "" ( empty string ) is the default
-     * @since 5.73
-     * @deprecated Since 5.89, use KTerminalLauncherJob instead
-     */
-    KSERVICE_DEPRECATED_VERSION(5, 89, "use KTerminalLauncherJob instead")
-    static void invokeTerminal(const QString &command, const QStringList &envs, const QString &workdir = QString(), const QByteArray &startup_id = "");
-
-#if KSERVICE_ENABLE_DEPRECATED_SINCE(5, 79)
-    /**
-     *
      * Invokes the standard terminal application.
      *
      * @param command the command to execute, can be empty.
@@ -176,28 +164,13 @@ public Q_SLOTS:
      *           "" ( empty string ) is the default
      *
      * @since 4.1
-     * @deprecated since 5,79, use invokeTerminal(const QString &command, const QStringList &envs, const QString &workdir, const QByteArray &startup_id) instead
      */
-    KSERVICE_DEPRECATED_VERSION(
-        5,
-        79,
-        "Use invokeTerminal(const QString &command, const QStringList &envs, const QString &workdir, const QByteArray &startup_id) instead")
-    static void invokeTerminal(const QString &command, const QString &workdir = QString(), const QByteArray &startup_id = "");
-#endif
-
-    /**
-     * Returns the configured default terminal application. This is compatible with
-     * the old config format from the KCM in Plasma < 5.21.
-     * @param command Command that should be executed in the terminal app
-     * @param workingDir Working directory for the terminal app.
-     * @return KServicePtr of terminal application.
-     * @since 5.78
-     * @deprecated Since 5.89, use KTerminalLauncherJob instead to launch the executable
-     */
-    KSERVICE_DEPRECATED_VERSION(5, 89, "use KTerminalLauncherJob instead to launch the executable")
-    static KServicePtr terminalApplication(const QString &command = QString(), const QString &workingDir = QString());
+    static void invokeTerminal(const QString &command,
+                               const QString &workdir = QString(),
+                               const QByteArray &startup_id = "");
 
 public:
+
 #if KSERVICE_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * Starts a service based on the (translated) name of the service.
@@ -221,16 +194,10 @@ public:
      * @deprecated Since 5.0, use startServiceByDesktopName or startServiceByDesktopPath
      */
     KSERVICE_DEPRECATED_VERSION(5, 0, "Use KToolInvocation::startServiceByDesktopName(...) or KToolInvocation::startServiceByDesktopPath(...)")
-    static int startServiceByName(const QString &_name,
-                                  const QString &URL,
-                                  QString *error = nullptr,
-                                  QString *serviceName = nullptr,
-                                  int *pid = nullptr,
-                                  const QByteArray &startup_id = QByteArray(),
-                                  bool noWait = false);
-#endif
+    static int startServiceByName(const QString &_name, const QString &URL,
+            QString *error = nullptr, QString *serviceName = nullptr, int *pid = nullptr,
+            const QByteArray &startup_id = QByteArray(), bool noWait = false);
 
-#if KSERVICE_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * Starts a service based on the (translated) name of the service.
      * E.g. "Web Browser"
@@ -253,16 +220,11 @@ public:
      * @deprecated Since 5.0, use startServiceByDesktopName or startServiceByDesktopPath
      */
     KSERVICE_DEPRECATED_VERSION(5, 0, "Use KToolInvocation::startServiceByDesktopName(...) or KToolInvocation::startServiceByDesktopPath(...)")
-    static int startServiceByName(const QString &_name,
-                                  const QStringList &URLs = QStringList(),
-                                  QString *error = nullptr,
-                                  QString *serviceName = nullptr,
-                                  int *pid = nullptr,
-                                  const QByteArray &startup_id = QByteArray(),
-                                  bool noWait = false);
+    static int startServiceByName(const QString &_name, const QStringList &URLs = QStringList(),
+            QString *error = nullptr, QString *serviceName = nullptr, int *pid = nullptr,
+            const QByteArray &startup_id = QByteArray(), bool noWait = false);
 #endif
 
-#if KSERVICE_ENABLE_DEPRECATED_SINCE(5, 82)
     /**
      * Starts a service based on the desktop path of the service.
      * E.g. "Applications/konqueror.desktop" or "/home/user/bla/myfile.desktop"
@@ -285,20 +247,12 @@ public:
      *
      * @deprecated since 5.0 use QDBusConnectionInterface::startService("org.kde.serviceName"),
      *   to start a unique application in order to make D-Bus calls to it (after ensuring that
-     *   it installs a D-Bus org.kde.serviceName.service file). Otherwise just use QProcess,
-     *   KIO::CommandLauncherJob or KIO::ApplicationLauncherJob.
+     *   it installs a D-Bus org.kde.serviceName.service file). Otherwise just use QProcess or KRun.
      */
-    KSERVICE_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "See API documentation")
-    static int startServiceByDesktopPath(const QString &_name,
-                                         const QString &URL,
-                                         QString *error = nullptr,
-                                         QString *serviceName = nullptr,
-                                         int *pid = nullptr,
-                                         const QByteArray &startup_id = QByteArray(),
-                                         bool noWait = false);
-#endif
+    static int startServiceByDesktopPath(const QString &_name, const QString &URL,
+                                         QString *error = nullptr, QString *serviceName = nullptr, int *pid = nullptr,
+                                         const QByteArray &startup_id = QByteArray(), bool noWait = false);
 
-#if KSERVICE_ENABLE_DEPRECATED_SINCE(5, 82)
     /**
      * Starts a service based on the desktop path of the service.
      * E.g. "Applications/konqueror.desktop" or "/home/user/bla/myfile.desktop"
@@ -319,20 +273,12 @@ public:
      * @return an error code indicating success (== 0) or failure (> 0).
      * @deprecated since 5.0 use QDBusConnectionInterface::startService("org.kde.serviceName"),
      *   to start a unique application in order to make D-Bus calls to it (after ensuring that
-     *   it installs a D-Bus org.kde.serviceName.service file). Otherwise just use QProcess,
-     *   KIO::CommandLauncherJob or KIO::ApplicationLauncherJob.
+     *   it installs a D-Bus org.kde.serviceName.service file). Otherwise just use QProcess or KRun.
      */
-    KSERVICE_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "See API documentation")
-    static int startServiceByDesktopPath(const QString &_name,
-                                         const QStringList &URLs = QStringList(),
-                                         QString *error = nullptr,
-                                         QString *serviceName = nullptr,
-                                         int *pid = nullptr,
-                                         const QByteArray &startup_id = QByteArray(),
-                                         bool noWait = false);
-#endif
+    static int startServiceByDesktopPath(const QString &_name, const QStringList &URLs = QStringList(),
+                                         QString *error = nullptr, QString *serviceName = nullptr, int *pid = nullptr,
+                                         const QByteArray &startup_id = QByteArray(), bool noWait = false);
 
-#if KSERVICE_ENABLE_DEPRECATED_SINCE(5, 82)
     /**
      * Starts a service based on the desktop name of the service.
      * E.g. "konqueror"
@@ -354,20 +300,12 @@ public:
      * @return an error code indicating success (== 0) or failure (> 0).
      * @deprecated since 5.0 use QDBusConnectionInterface::startService("org.kde.serviceName"),
      *   to start a unique application in order to make D-Bus calls to it (after ensuring that
-     *   it installs a D-Bus org.kde.serviceName.service file). Otherwise just use QProcess,
-     *   KIO::CommandLauncherJob or KIO::ApplicationLauncherJob.
+     *   it installs a D-Bus org.kde.serviceName.service file). Otherwise just use QProcess or KRun.
      */
-    KSERVICE_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "See API documentation")
-    static int startServiceByDesktopName(const QString &_name,
-                                         const QString &URL,
-                                         QString *error = nullptr,
-                                         QString *serviceName = nullptr,
-                                         int *pid = nullptr,
-                                         const QByteArray &startup_id = QByteArray(),
-                                         bool noWait = false);
-#endif
+    static int startServiceByDesktopName(const QString &_name, const QString &URL,
+                                         QString *error = nullptr, QString *serviceName = nullptr, int *pid = nullptr,
+                                         const QByteArray &startup_id = QByteArray(), bool noWait = false);
 
-#if KSERVICE_ENABLE_DEPRECATED_SINCE(5, 82)
     /**
      * Starts a service based on the desktop name of the service.
      * E.g. "konqueror"
@@ -389,20 +327,12 @@ public:
      * @return an error code indicating success (== 0) or failure (> 0).
      * @deprecated since 5.0 use QDBusConnectionInterface::startService("org.kde.serviceName"),
      *   to start a unique application in order to make D-Bus calls to it (after ensuring that
-     *   it installs a D-Bus org.kde.serviceName.service file). Otherwise just use QProcess,
-     *   KIO::CommandLauncherJob or KIO::ApplicationLauncherJob.
+     *   it installs a D-Bus org.kde.serviceName.service file). Otherwise just use QProcess or KRun.
      */
-    KSERVICE_DEPRECATED_VERSION_BELATED(5, 82, 5, 0, "See API documentation")
-    static int startServiceByDesktopName(const QString &_name,
-                                         const QStringList &URLs = QStringList(),
-                                         QString *error = nullptr,
-                                         QString *serviceName = nullptr,
-                                         int *pid = nullptr,
-                                         const QByteArray &startup_id = QByteArray(),
-                                         bool noWait = false);
-#endif
+    static int startServiceByDesktopName(const QString &_name, const QStringList &URLs = QStringList(),
+                                         QString *error = nullptr, QString *serviceName = nullptr, int *pid = nullptr,
+                                         const QByteArray &startup_id = QByteArray(), bool noWait = false);
 
-#if KSERVICE_ENABLE_DEPRECATED_SINCE(5, 83)
     /**
      * Starts a program via kdeinit.
      *
@@ -419,15 +349,9 @@ public:
      * @param startup_id for app startup notification, "0" for none,
      *           "" ( empty string ) is the default
      * @return an error code indicating success (== 0) or failure (> 0).
-     * @deprecated since 5.83, use CommandLauncherJob instead
      */
-    KSERVICE_DEPRECATED_VERSION(5, 83, "use CommandLauncherJob instead")
-    static int kdeinitExec(const QString &name,
-                           const QStringList &args = QStringList(),
-                           QString *error = nullptr,
-                           int *pid = nullptr,
-                           const QByteArray &startup_id = QByteArray());
-#endif
+    static int kdeinitExec(const QString &name, const QStringList &args = QStringList(),
+                           QString *error = nullptr, int *pid = nullptr, const QByteArray &startup_id = QByteArray());
 
     /**
      * Starts a program via kdeinit and wait for it to finish.
@@ -445,20 +369,13 @@ public:
      * @param startup_id for app startup notification, "0" for none,
      *           "" ( empty string ) is the default
      * @return an error code indicating success (== 0) or failure (> 0).
-     * @deprecated since 5.88, kdeinit is deprecated, launch the executable manually
      */
-    KSERVICE_DEPRECATED_VERSION(5, 89, "kdeinit is deprecated, launch the executable manually")
-    static int kdeinitExecWait(const QString &name,
-                               const QStringList &args = QStringList(),
-                               QString *error = nullptr,
-                               int *pid = nullptr,
-                               const QByteArray &startup_id = QByteArray());
+    static int kdeinitExecWait(const QString &name, const QStringList &args = QStringList(),
+                               QString *error = nullptr, int *pid = nullptr, const QByteArray &startup_id = QByteArray());
 
     /**
      * Ensures that kdeinit5 and klauncher are running.
-     * @deprecated Since 5.88, kdeinit is deprecated
      */
-    KSERVICE_DEPRECATED_VERSION(5, 89, "kdeinit is deprecated")
     static void ensureKdeinitRunning();
 
 Q_SIGNALS:
@@ -470,15 +387,10 @@ Q_SIGNALS:
 
 private:
     int startServiceInternal(const char *_function,
-                             const QString &_name,
-                             const QStringList &URLs,
-                             QString *error,
-                             QString *serviceName,
-                             int *pid,
-                             const QByteArray &startup_id,
-                             bool noWait,
-                             const QString &workdir = QString(),
-                             const QStringList &envs = QStringList());
+                             const QString &_name, const QStringList &URLs,
+                             QString *error, QString *serviceName, int *pid,
+                             const QByteArray &startup_id, bool noWait,
+                             const QString &workdir = QString());
     static bool isMainThreadActive(QString *error = nullptr);
 
     KToolInvocationPrivate *const d;
@@ -486,4 +398,4 @@ private:
 };
 
 #endif
-#endif
+
